@@ -10,11 +10,21 @@ Usage::
     client: NetworkManagerClient = boto3.client("networkmanager")
     ```
 """
-import sys
 from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
+from mypy_boto3_networkmanager.literals import (
+    DescribeGlobalNetworksPaginatorName,
+    GetConnectionsPaginatorName,
+    GetCustomerGatewayAssociationsPaginatorName,
+    GetDevicesPaginatorName,
+    GetLinkAssociationsPaginatorName,
+    GetLinksPaginatorName,
+    GetSitesPaginatorName,
+    GetTransitGatewayConnectPeerAssociationsPaginatorName,
+    GetTransitGatewayRegistrationsPaginatorName,
+)
 from mypy_boto3_networkmanager.paginator import (
     DescribeGlobalNetworksPaginator,
     GetConnectionsPaginator,
@@ -66,12 +76,6 @@ from mypy_boto3_networkmanager.type_defs import (
     UpdateSiteResponseTypeDef,
 )
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
-
 __all__ = ("NetworkManagerClient",)
 
 
@@ -96,7 +100,7 @@ class Exceptions:
 
 class NetworkManagerClient:
     """
-    [NetworkManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client)
+    [NetworkManager.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client)
     """
 
     meta: ClientMeta
@@ -106,14 +110,14 @@ class NetworkManagerClient:
         self, CustomerGatewayArn: str, GlobalNetworkId: str, DeviceId: str, LinkId: str = None
     ) -> AssociateCustomerGatewayResponseTypeDef:
         """
-        [Client.associate_customer_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
+        [Client.associate_customer_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
         """
 
     def associate_link(
         self, GlobalNetworkId: str, DeviceId: str, LinkId: str
     ) -> AssociateLinkResponseTypeDef:
         """
-        [Client.associate_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
+        [Client.associate_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
         """
 
     def associate_transit_gateway_connect_peer(
@@ -124,12 +128,12 @@ class NetworkManagerClient:
         LinkId: str = None,
     ) -> AssociateTransitGatewayConnectPeerResponseTypeDef:
         """
-        [Client.associate_transit_gateway_connect_peer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
+        [Client.associate_transit_gateway_connect_peer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
         """
 
     def create_connection(
@@ -143,7 +147,7 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateConnectionResponseTypeDef:
         """
-        [Client.create_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
+        [Client.create_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
         """
 
     def create_device(
@@ -160,14 +164,14 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDeviceResponseTypeDef:
         """
-        [Client.create_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.create_device)
+        [Client.create_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.create_device)
         """
 
     def create_global_network(
         self, Description: str = None, Tags: List["TagTypeDef"] = None
     ) -> CreateGlobalNetworkResponseTypeDef:
         """
-        [Client.create_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
+        [Client.create_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
         """
 
     def create_link(
@@ -181,7 +185,7 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateLinkResponseTypeDef:
         """
-        [Client.create_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.create_link)
+        [Client.create_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.create_link)
         """
 
     def create_site(
@@ -192,69 +196,69 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateSiteResponseTypeDef:
         """
-        [Client.create_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.create_site)
+        [Client.create_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.create_site)
         """
 
     def delete_connection(
         self, GlobalNetworkId: str, ConnectionId: str
     ) -> DeleteConnectionResponseTypeDef:
         """
-        [Client.delete_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
+        [Client.delete_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
         """
 
     def delete_device(self, GlobalNetworkId: str, DeviceId: str) -> DeleteDeviceResponseTypeDef:
         """
-        [Client.delete_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
+        [Client.delete_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
         """
 
     def delete_global_network(self, GlobalNetworkId: str) -> DeleteGlobalNetworkResponseTypeDef:
         """
-        [Client.delete_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
+        [Client.delete_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
         """
 
     def delete_link(self, GlobalNetworkId: str, LinkId: str) -> DeleteLinkResponseTypeDef:
         """
-        [Client.delete_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
+        [Client.delete_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
         """
 
     def delete_site(self, GlobalNetworkId: str, SiteId: str) -> DeleteSiteResponseTypeDef:
         """
-        [Client.delete_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
+        [Client.delete_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
         """
 
     def deregister_transit_gateway(
         self, GlobalNetworkId: str, TransitGatewayArn: str
     ) -> DeregisterTransitGatewayResponseTypeDef:
         """
-        [Client.deregister_transit_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
+        [Client.deregister_transit_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
         """
 
     def describe_global_networks(
         self, GlobalNetworkIds: List[str] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeGlobalNetworksResponseTypeDef:
         """
-        [Client.describe_global_networks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
+        [Client.describe_global_networks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
         """
 
     def disassociate_customer_gateway(
         self, GlobalNetworkId: str, CustomerGatewayArn: str
     ) -> DisassociateCustomerGatewayResponseTypeDef:
         """
-        [Client.disassociate_customer_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
+        [Client.disassociate_customer_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
         """
 
     def disassociate_link(
         self, GlobalNetworkId: str, DeviceId: str, LinkId: str
     ) -> DisassociateLinkResponseTypeDef:
         """
-        [Client.disassociate_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
+        [Client.disassociate_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
         """
 
     def disassociate_transit_gateway_connect_peer(
         self, GlobalNetworkId: str, TransitGatewayConnectPeerArn: str
     ) -> DisassociateTransitGatewayConnectPeerResponseTypeDef:
         """
-        [Client.disassociate_transit_gateway_connect_peer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
+        [Client.disassociate_transit_gateway_connect_peer documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
         """
 
     def generate_presigned_url(
@@ -265,7 +269,7 @@ class NetworkManagerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
         """
 
     def get_connections(
@@ -277,7 +281,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetConnectionsResponseTypeDef:
         """
-        [Client.get_connections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
+        [Client.get_connections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
         """
 
     def get_customer_gateway_associations(
@@ -288,7 +292,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetCustomerGatewayAssociationsResponseTypeDef:
         """
-        [Client.get_customer_gateway_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
+        [Client.get_customer_gateway_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
         """
 
     def get_devices(
@@ -300,7 +304,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetDevicesResponseTypeDef:
         """
-        [Client.get_devices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
+        [Client.get_devices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
         """
 
     def get_link_associations(
@@ -312,7 +316,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetLinkAssociationsResponseTypeDef:
         """
-        [Client.get_link_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
+        [Client.get_link_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
         """
 
     def get_links(
@@ -326,7 +330,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetLinksResponseTypeDef:
         """
-        [Client.get_links documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.get_links)
+        [Client.get_links documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.get_links)
         """
 
     def get_sites(
@@ -337,7 +341,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetSitesResponseTypeDef:
         """
-        [Client.get_sites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
+        [Client.get_sites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
         """
 
     def get_transit_gateway_connect_peer_associations(
@@ -348,7 +352,7 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetTransitGatewayConnectPeerAssociationsResponseTypeDef:
         """
-        [Client.get_transit_gateway_connect_peer_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
+        [Client.get_transit_gateway_connect_peer_associations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
         """
 
     def get_transit_gateway_registrations(
@@ -359,29 +363,29 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetTransitGatewayRegistrationsResponseTypeDef:
         """
-        [Client.get_transit_gateway_registrations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
+        [Client.get_transit_gateway_registrations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
+        [Client.list_tags_for_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
         """
 
     def register_transit_gateway(
         self, GlobalNetworkId: str, TransitGatewayArn: str
     ) -> RegisterTransitGatewayResponseTypeDef:
         """
-        [Client.register_transit_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
+        [Client.register_transit_gateway documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
+        [Client.tag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
+        [Client.untag_resource documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
         """
 
     def update_connection(
@@ -393,7 +397,7 @@ class NetworkManagerClient:
         Description: str = None,
     ) -> UpdateConnectionResponseTypeDef:
         """
-        [Client.update_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
+        [Client.update_connection documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
         """
 
     def update_device(
@@ -410,14 +414,14 @@ class NetworkManagerClient:
         SiteId: str = None,
     ) -> UpdateDeviceResponseTypeDef:
         """
-        [Client.update_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.update_device)
+        [Client.update_device documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.update_device)
         """
 
     def update_global_network(
         self, GlobalNetworkId: str, Description: str = None
     ) -> UpdateGlobalNetworkResponseTypeDef:
         """
-        [Client.update_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
+        [Client.update_global_network documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
         """
 
     def update_link(
@@ -430,7 +434,7 @@ class NetworkManagerClient:
         Provider: str = None,
     ) -> UpdateLinkResponseTypeDef:
         """
-        [Client.update_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.update_link)
+        [Client.update_link documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.update_link)
         """
 
     def update_site(
@@ -441,69 +445,69 @@ class NetworkManagerClient:
         Location: "LocationTypeDef" = None,
     ) -> UpdateSiteResponseTypeDef:
         """
-        [Client.update_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Client.update_site)
+        [Client.update_site documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Client.update_site)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["describe_global_networks"]
+        self, operation_name: DescribeGlobalNetworksPaginatorName
     ) -> DescribeGlobalNetworksPaginator:
         """
-        [Paginator.DescribeGlobalNetworks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
+        [Paginator.DescribeGlobalNetworks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["get_connections"]) -> GetConnectionsPaginator:
+    def get_paginator(self, operation_name: GetConnectionsPaginatorName) -> GetConnectionsPaginator:
         """
-        [Paginator.GetConnections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
+        [Paginator.GetConnections documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["get_customer_gateway_associations"]
+        self, operation_name: GetCustomerGatewayAssociationsPaginatorName
     ) -> GetCustomerGatewayAssociationsPaginator:
         """
-        [Paginator.GetCustomerGatewayAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
+        [Paginator.GetCustomerGatewayAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["get_devices"]) -> GetDevicesPaginator:
+    def get_paginator(self, operation_name: GetDevicesPaginatorName) -> GetDevicesPaginator:
         """
-        [Paginator.GetDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
+        [Paginator.GetDevices documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["get_link_associations"]
+        self, operation_name: GetLinkAssociationsPaginatorName
     ) -> GetLinkAssociationsPaginator:
         """
-        [Paginator.GetLinkAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
+        [Paginator.GetLinkAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["get_links"]) -> GetLinksPaginator:
+    def get_paginator(self, operation_name: GetLinksPaginatorName) -> GetLinksPaginator:
         """
-        [Paginator.GetLinks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
+        [Paginator.GetLinks documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)
         """
 
     @overload
-    def get_paginator(self, operation_name: Literal["get_sites"]) -> GetSitesPaginator:
+    def get_paginator(self, operation_name: GetSitesPaginatorName) -> GetSitesPaginator:
         """
-        [Paginator.GetSites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
+        [Paginator.GetSites documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["get_transit_gateway_connect_peer_associations"]
+        self, operation_name: GetTransitGatewayConnectPeerAssociationsPaginatorName
     ) -> GetTransitGatewayConnectPeerAssociationsPaginator:
         """
-        [Paginator.GetTransitGatewayConnectPeerAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
+        [Paginator.GetTransitGatewayConnectPeerAssociations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)
         """
 
     @overload
     def get_paginator(
-        self, operation_name: Literal["get_transit_gateway_registrations"]
+        self, operation_name: GetTransitGatewayRegistrationsPaginatorName
     ) -> GetTransitGatewayRegistrationsPaginator:
         """
-        [Paginator.GetTransitGatewayRegistrations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.60/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
+        [Paginator.GetTransitGatewayRegistrations documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.61/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)
         """
