@@ -13,10 +13,18 @@ import sys
 from datetime import datetime
 from typing import List
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_networkmanager.literals import (
+    ConnectionState,
+    CustomerGatewayAssociationState,
+    DeviceState,
+    GlobalNetworkState,
+    LinkAssociationState,
+    LinkState,
+    SiteState,
+    TransitGatewayConnectPeerAssociationState,
+    TransitGatewayRegistrationState,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -92,7 +100,7 @@ ConnectionTypeDef = TypedDict(
         "ConnectedLinkId": str,
         "Description": str,
         "CreatedAt": datetime,
-        "State": Literal["PENDING", "AVAILABLE", "DELETING", "UPDATING"],
+        "State": ConnectionState,
         "Tags": List["TagTypeDef"],
     },
     total=False,
@@ -105,7 +113,7 @@ CustomerGatewayAssociationTypeDef = TypedDict(
         "GlobalNetworkId": str,
         "DeviceId": str,
         "LinkId": str,
-        "State": Literal["PENDING", "AVAILABLE", "DELETING", "DELETED"],
+        "State": CustomerGatewayAssociationState,
     },
     total=False,
 )
@@ -125,7 +133,7 @@ DeviceTypeDef = TypedDict(
         "Location": "LocationTypeDef",
         "SiteId": str,
         "CreatedAt": datetime,
-        "State": Literal["PENDING", "AVAILABLE", "DELETING", "UPDATING"],
+        "State": DeviceState,
         "Tags": List["TagTypeDef"],
     },
     total=False,
@@ -138,7 +146,7 @@ GlobalNetworkTypeDef = TypedDict(
         "GlobalNetworkArn": str,
         "Description": str,
         "CreatedAt": datetime,
-        "State": Literal["PENDING", "AVAILABLE", "DELETING", "UPDATING"],
+        "State": GlobalNetworkState,
         "Tags": List["TagTypeDef"],
     },
     total=False,
@@ -150,7 +158,7 @@ LinkAssociationTypeDef = TypedDict(
         "GlobalNetworkId": str,
         "DeviceId": str,
         "LinkId": str,
-        "LinkAssociationState": Literal["PENDING", "AVAILABLE", "DELETING", "DELETED"],
+        "LinkAssociationState": LinkAssociationState,
     },
     total=False,
 )
@@ -167,7 +175,7 @@ LinkTypeDef = TypedDict(
         "Bandwidth": "BandwidthTypeDef",
         "Provider": str,
         "CreatedAt": datetime,
-        "State": Literal["PENDING", "AVAILABLE", "DELETING", "UPDATING"],
+        "State": LinkState,
         "Tags": List["TagTypeDef"],
     },
     total=False,
@@ -186,7 +194,7 @@ SiteTypeDef = TypedDict(
         "Description": str,
         "Location": "LocationTypeDef",
         "CreatedAt": datetime,
-        "State": Literal["PENDING", "AVAILABLE", "DELETING", "UPDATING"],
+        "State": SiteState,
         "Tags": List["TagTypeDef"],
     },
     total=False,
@@ -201,14 +209,14 @@ TransitGatewayConnectPeerAssociationTypeDef = TypedDict(
         "GlobalNetworkId": str,
         "DeviceId": str,
         "LinkId": str,
-        "State": Literal["PENDING", "AVAILABLE", "DELETING", "DELETED"],
+        "State": TransitGatewayConnectPeerAssociationState,
     },
     total=False,
 )
 
 TransitGatewayRegistrationStateReasonTypeDef = TypedDict(
     "TransitGatewayRegistrationStateReasonTypeDef",
-    {"Code": Literal["PENDING", "AVAILABLE", "DELETING", "DELETED", "FAILED"], "Message": str},
+    {"Code": TransitGatewayRegistrationState, "Message": str},
     total=False,
 )
 
